@@ -1,8 +1,11 @@
 package Test::Class::Moose;
-$Test::Class::Moose::VERSION = '0.62';
+
 # ABSTRACT: Serious testing for serious Perl
 
 use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose 2.0000;
 use Carp;
 use namespace::autoclean;
@@ -12,13 +15,7 @@ use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Config;
 use Test::Class::Moose::Deprecated;
 
-has 'test_report' => (
-    is     => 'rw',
-    isa    => 'Test::Class::Moose::Report',
-    writer => '__set_test_report',
-);
-
-sub __create_attributes {
+sub __sub_attr_declaration_code {
 
     # XXX sharing this behavior here because my first attempt at creating a
     # role was a complete failure. MooseX::MethodAttributes can help here, but
@@ -105,13 +102,20 @@ DECLARE_ATTRIBUTES
 }
 
 BEGIN {
-    eval __PACKAGE__->__create_attributes;
+    eval __PACKAGE__->__sub_attr_declaration_code;
     croak($@) if $@;
 }
 
+has 'test_report' => (
+    is  => 'ro',
+    isa => 'Test::Class::Moose::Report',
+);
+
 has 'test_class' => (
-    is  => 'rw',
-    isa => 'Str',
+    is       => 'ro',
+    isa      => 'Str',
+    init_arg => undef,
+    default  => sub { ref $_[0] },
 );
 
 has 'test_skip' => (
@@ -154,8 +158,8 @@ END
 # XXX - this is only necessary for backwards compatibility, where people call
 # Test::Class::Moose->new(...)->runtests() instead of
 # Test::Class::Moose::Runner->new(...)->runtests()
-my %config_attrs = map { $_->init_arg => 1}
-    Test::Class::Moose::Config->meta->get_all_attributes;
+my %config_attrs = map { $_->init_arg => 1 }
+  Test::Class::Moose::Config->meta->get_all_attributes;
 around 'BUILDARGS' => sub {
     my $orig  = shift;
     my $class = shift;
@@ -163,7 +167,7 @@ around 'BUILDARGS' => sub {
     my $p = $class->$orig(@_);
 
     my %config_p
-        = map { $_ => delete $p->{$_} } grep { $config_attrs{$_} } keys %{$p};
+      = map { $_ => delete $p->{$_} } grep { $config_attrs{$_} } keys %{$p};
     $p->{_config_p} = \%config_p;
 
     return $p;
@@ -175,37 +179,21 @@ sub runtests {
 
     Test::Class::Moose::Deprecated::deprecated(
         message =>
-            'Calling runtests() on a Test::Class::Moose object is deprecated.'
-            . ' Use Test::Class::Moose::Runner instead.',
+          'Calling runtests() on a Test::Class::Moose object is deprecated.'
+          . ' Use Test::Class::Moose::Runner instead.',
         feature => 'Test::Class::Moose->runtests',
     );
 
-    # The only way this object won't have a _runner set is if someone calls
-    # ->new() on their test class (which subclasses Test::Class::Moose) and
-    # then calls ->runtests() on it, which has never been documented as
-    # working.
-    carp 'Calling runtests() on a Test::Class::Moose object is deprecated.'
-        . ' Use Test::Class::Moose::Runner instead.';
-
-
     require Test::Class::Moose::Runner;
-    my $runner
-        = Test::Class::Moose::Runner->new( $self->_config_p );
+    my $runner = Test::Class::Moose::Runner->new( $self->_config_p );
 
     return $runner->runtests();
 }
 
-sub BUILD {
-    my $self = shift;
-
-    # stash that name lest something change it later. Paranoid?
-    $self->test_class( $self->meta->name );
-}
-
 sub _tcm_make_test_class_instances {
-    my ( $test_class, $args ) = @_;
+    my $test_class = shift;
 
-    return ( $test_class => $test_class->new($args) );
+    return ( $test_class => $test_class->new(@_) );
 }
 
 sub test_methods {
@@ -218,7 +206,7 @@ sub test_methods {
         next if $method->isa('Moose::Meta::Method::Accessor');
 
         my $class = ref $self;
-        my $name = $method->name;
+        my $name  = $method->name;
         next
           unless $name =~ /^test_/
           || Test::Class::Moose::AttributeRegistry->has_test_attribute(
@@ -252,7 +240,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -308,6 +296,8 @@ you get:
 Better docs will come later. You should already know how to use Moose and
 L<Test::Class>.
 
+=for Pod::Coverage Tags Tests runtests
+
 =head1 BASICS
 
 =head2 Inheriting from Test::Class::Moose
@@ -839,6 +829,7 @@ wrong).
         my $system = $time->system;
         # do with these as you will
     }
+    diag "Number of test classes: "   . $report->num_test_classes;
     diag "Number of test instances: " . $report->num_test_instances;
     diag "Number of test methods: "   . $report->num_test_methods;
     diag "Number of tests:        "   . $report->num_tests;
@@ -1122,7 +1113,7 @@ Udo Oji <Velti@signor.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
