@@ -1,16 +1,18 @@
 package Test::Class::Moose::AttributeRegistry;
-$Test::Class::Moose::AttributeRegistry::VERSION = '0.62';
+
 ## ABSTRACT: Global registry of tags by class and method.
 
 use strict;
 use warnings;
 
+our $VERSION = '0.67';
+
 use Carp;
 use Class::MOP;
 use List::MoreUtils qw( any uniq );
 
 my %BY_METHOD = (
-    tags => {}, # {$method}{$test_class}
+    tags  => {},    # {$method}{$test_class}
     plans => {},
 );
 
@@ -18,7 +20,7 @@ sub add_plan {
     my ( $class, $test_class, $method, $plan ) = @_;
     if ( defined $plan ) {
         $plan =~ s/\D//g;
-        undef $plan unless $plan =~ /\d/; # no_plan
+        undef $plan unless $plan =~ /\d/;    # no_plan
     }
     $BY_METHOD{plans}{$method}{$test_class} = $plan;
 }
@@ -39,11 +41,11 @@ sub add_tags {
     my @tags_copy = @{$tags};
 
     # check for additions or deletions to the inherited tag list
-    if (any { /^[-+]/ } @tags_copy) {
-        @tags_copy = $class->_augment_tags($test_class, $method, $tags);
+    if ( any {/^[-+]/} @tags_copy ) {
+        @tags_copy = $class->_augment_tags( $test_class, $method, $tags );
     }
 
-    foreach my $tag ( @tags_copy ) {
+    foreach my $tag (@tags_copy) {
         if ( $tag !~ /^\w+$/ ) {
             die "tags must be alphanumeric\n";
         }
@@ -52,7 +54,9 @@ sub add_tags {
     # dedupe tags
     my %tags = map { $_ => 1 } @tags_copy;
 
-    if (exists $BY_METHOD{tags}{$method} && exists $BY_METHOD{tags}{$method}{$test_class}) {
+    if (   exists $BY_METHOD{tags}{$method}
+        && exists $BY_METHOD{tags}{$method}{$test_class} )
+    {
         die
           "tags for $test_class->$method already exists, method redefinition perhaps?\n";
     }
@@ -98,10 +102,12 @@ sub method_has_tag {
     # avoid auto-vivication
     return if not exists $BY_METHOD{tags}{$method};
 
-    if (not exists $BY_METHOD{tags}{$method}{$test_class}) {
+    if ( not exists $BY_METHOD{tags}{$method}{$test_class} ) {
+
         # If this method has no tag data at all, then inherit the tags from
         # from the superclass
-        $BY_METHOD{tags}{$method}{$test_class} = $class->_superclass_tags($test_class, $method);
+        $BY_METHOD{tags}{$method}{$test_class}
+          = $class->_superclass_tags( $test_class, $method );
     }
 
     return exists $BY_METHOD{tags}{$method}{$test_class}{$tag};
@@ -119,7 +125,7 @@ sub _superclass_tags {
     my $method_meta;
 
     $method_meta = $test_class_meta->find_next_method_by_name($method)
-        if $test_class_meta->can('find_next_method_by_name');
+      if $test_class_meta->can('find_next_method_by_name');
 
     if ( !$method_meta ) {
 
@@ -137,14 +143,16 @@ sub _superclass_tags {
 
     my $super_test_class = $method_meta->package_name();
     if ( exists $BY_METHOD{tags}{$method}{$super_test_class} ) {
+
         # shallow copy the superclass method's tags, because it's possible to
         # change add/remove items from the subclass's list later
-        my %tags = map { $_ => 1 } keys %{ $BY_METHOD{tags}{$method}{$super_test_class} };
+        my %tags = map { $_ => 1 }
+          keys %{ $BY_METHOD{tags}{$method}{$super_test_class} };
         return \%tags;
     }
 
     # nothing defined at this level, recurse
-    return $class->_superclass_tags($super_test_class, $method);
+    return $class->_superclass_tags( $super_test_class, $method );
 }
 
 sub _augment_tags {
@@ -154,20 +162,22 @@ sub _augment_tags {
     croak("no method specified") if not defined $method;
 
     # Get the base list from the superclass
-    my $tag_list = $class->_superclass_tags($test_class, $method);
+    my $tag_list = $class->_superclass_tags( $test_class, $method );
 
-    for my $tag_definition (@{$tags}) {
-        my $direction = substr($tag_definition, 0, 1);
-        my $tag = substr($tag_definition, 1);
-        if ($direction eq '+') {
+    for my $tag_definition ( @{$tags} ) {
+        my $direction = substr( $tag_definition, 0, 1 );
+        my $tag = substr( $tag_definition, 1 );
+        if ( $direction eq '+' ) {
             $tag_list->{$tag} = 1;
         }
-        elsif ($direction eq '-') {
+        elsif ( $direction eq '-' ) {
+
             # die here if the tag wasn't inherited?
             delete $tag_list->{$tag};
         }
         else {
-            die "$test_class->$method attempting to override and modify tags, did you forget a '+'?\n";
+            die
+              "$test_class->$method attempting to override and modify tags, did you forget a '+'?\n";
         }
     }
 
@@ -186,7 +196,7 @@ Test::Class::Moose::AttributeRegistry - Global registry of tags by class and met
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -235,9 +245,14 @@ for it.
 
 Find all tags defined for all methods.  Returns a sorted list of tags.
 
+=item class_has_tag( $class, $tag )
+
+Returns a boolean (0|1) indicating whether the given class has any method with
+the specified tag.
+
 =item method_has_tag( $class, $method, $tag )
 
-Returns a boolean (0|1), indicating whether the given method in the given class
+Returns a boolean (0|1) indicating whether the given method in the given class
 has the specified tag.
 
 =back
@@ -270,7 +285,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
