@@ -1,8 +1,11 @@
 package Test::Class::Moose::Config;
-$Test::Class::Moose::Config::VERSION = '0.62';
+
 # ABSTRACT: Configuration information for Test::Class::Moose
 
 use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose;
 use Moose::Util::TypeConstraints;
 use TAP::Formatter::Color;
@@ -51,7 +54,7 @@ has 'use_environment' => (
 );
 
 has 'test_class' => (
-    is  => 'rw',
+    is  => 'ro',
     isa => 'Str',
 );
 
@@ -100,10 +103,10 @@ has 'test_classes' => (
 sub args {
     my $self = shift;
 
-    return {
+    return (
         map { defined $self->$_ ? ( $_ => $self->$_ ) : () }
         map { $_->name } $self->meta->get_all_attributes
-    };
+    );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -118,7 +121,7 @@ Test::Class::Moose::Config - Configuration information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -140,16 +143,16 @@ kept here to minimize namespace pollution in L<Test::Class::Moose>.
 
 =head1 ATTRIBUTES
 
-=head2 * C<show_timing>
+=head2 C<show_timing>
 
 Boolean. Will display verbose information on the amount of time it takes each
 test class/test method to run.
 
-=head2 * C<statistics>
+=head2 C<statistics>
 
 Boolean. Will display number of classes, test methods and tests run.
 
-=head2 * C<use_environment>
+=head2 C<use_environment>
 
 Boolean.  Sets show_timing and statistics to true if your test harness is running verbosely, false otherwise.
 
@@ -211,7 +214,7 @@ Boolean. Will run test classes in a random order.
 
  my $tests = Some::Test::Class->new($test_suite->test_configuration->args);
 
-Returns a hash reference of the args used to build the configuration. Used in
+Returns a hash of the args used to build the configuration. Used in
 testing. You probably won't need it.
 
 =head1 BUGS
@@ -268,7 +271,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
