@@ -1,10 +1,13 @@
 package Test::Class::Moose::Deprecated;
-$Test::Class::Moose::Deprecated::VERSION = '0.62';
+
 # ABSTRACT: Managed deprecation warnings for Test::Class::Moose
 
+use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Package::DeprecationManager -deprecations => {
-    'Test::Class::Moose->runtests'              => '0.55',
-    'Test::Class::Moose::Report->current_class' => '0.61',
+    'Test::Class::Moose->runtests' => '0.55',
 };
 
 1;
@@ -19,7 +22,7 @@ Test::Class::Moose::Deprecated - Managed deprecation warnings for Test::Class::M
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 DESCRIPTION
 
@@ -44,12 +47,6 @@ This was deprecated in version 0.55.
 
 Use L<Test::Class::Moose::Runner> to run tests instead.
 
-=head2 Test::Class::Moose::Report->current_class
-
-This was deprecated in version 0.61.
-
-Use L<Test::Class::Moose::Report->current_instance> instead.
-
 =head1 AUTHORS
 
 =over 4
@@ -66,7 +63,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
