@@ -1,7 +1,11 @@
 package Test::Class::Moose::Report::Instance;
-$Test::Class::Moose::Report::Instance::VERSION = '0.62';
+
 # ABSTRACT: Reporting on test classes
 
+use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose;
 use Carp;
 use namespace::autoclean;
@@ -10,8 +14,20 @@ with qw(
   Test::Class::Moose::Role::Reporting
 );
 
+has test_startup_method => (
+    is     => 'rw',
+    isa    => 'Test::Class::Moose::Report::Method',
+    writer => 'set_test_startup_method',
+);
+
+has test_shutdown_method => (
+    is     => 'rw',
+    isa    => 'Test::Class::Moose::Report::Method',
+    writer => 'set_test_shutdown_method',
+);
+
 has test_methods => (
-    is      => 'rw',
+    is      => 'ro',
     traits  => ['Array'],
     isa     => 'ArrayRef[Test::Class::Moose::Report::Method]',
     default => sub { [] },
@@ -22,12 +38,6 @@ has test_methods => (
     },
 );
 
-has 'error' => (
-    is        => 'rw',
-    isa       => 'Str',
-    predicate => 'has_error',
-);
-
 sub current_method {
     my $self = shift;
     return $self->test_methods->[-1];
@@ -47,7 +57,7 @@ Test::Class::Moose::Report::Instance - Reporting on test classes
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 DESCRIPTION
 
@@ -59,22 +69,20 @@ L<Test::Class::Moose::Role::Reporting>.
 
 =head1 ATTRIBUTES
 
-=head2 C<test_methods>
+See L<Test::Class::Moose::Role::Reporting> for additional attributes.
 
-Returns an array reference of L<Test::Class::Moose::Report::Method>
-objects.
+=head2 C<class>
+
+The L<Test::Class::Moose::Report::Class> for this instance.
 
 =head2 C<all_test_methods>
 
 Returns an array of L<Test::Class::Moose::Report::Method> objects.
 
-=head2 C<error>
+=head2 C<current_method>
 
-If this class could not be run, returns a string explaining the error.
-
-=head2 C<has_error>
-
-Returns a boolean indicating whether or not the class has an error.
+Returns the current (really, most recent)
+L<Test::Class::Moose::Report::Method> object that is being run.
 
 =head1 AUTHORS
 
@@ -92,7 +100,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
