@@ -1,42 +1,54 @@
 package Test::Class::Moose::Report::Time;
-$Test::Class::Moose::Report::Time::VERSION = '0.62';
+
 # ABSTRACT: Reporting object for timing
 
+use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose;
 use Benchmark qw(timestr :hireswallclock);
+use List::Util qw( max );
 use namespace::autoclean;
 
-has 'real'             => ( is => 'ro', isa => 'Num',       required => 1 );
-has 'user'             => ( is => 'ro', isa => 'Num',       required => 1 );
-has 'system'           => ( is => 'ro', isa => 'Num',       required => 1 );
-has '_children_user'   => ( is => 'ro', isa => 'Num',       required => 1 );
-has '_children_system' => ( is => 'ro', isa => 'Num',       required => 1 );
-has '_iters'           => ( is => 'ro', isa => 'Num',       required => 1 );
-has '_timediff'        => ( is => 'ro', isa => 'Benchmark', required => 1 );
+{
+    my @fields = qw( real user system _children_user _children_system );
+    for my $i ( 0 .. $#fields ) {
+        has $fields[$i] => (
+            is       => 'ro',
+            isa      => 'Num',
+            lazy     => 1,
+            default  => sub { max( $_[0]->_timediff->[$i], 0 ) },
+            init_arg => undef,
+        );
+    }
+}
 
-around 'BUILDARGS' => sub {
-    my ( $orig, $class, $timediff ) = @_;
-    my %args;
-    @args{
-        qw/
-          real
-          user
-          system
-          _children_user
-          _children_system
-          _iters
-          /
-      }
-      = @$timediff;
-    $args{_timediff} = $timediff;
-    return $class->$orig(%args);
-};
+has '_iters' => (
+    is       => 'ro',
+    isa      => 'Num',
+    lazy     => 1,
+    default  => sub { $_[0]->_timediff->[5] },
+    init_arg => undef,
+);
+
+has '_timediff' => (
+    is       => 'ro',
+    isa      => 'Benchmark',
+    required => 1,
+    init_arg => 'timediff',
+);
 
 sub duration {
     my $self = shift;
     return timestr( $self->_timediff );
 }
 
+sub as_hashref {
+    my $self = shift;
+    return { map { $_ => $self->$_ } qw( real user system ) };
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -51,7 +63,7 @@ Test::Class::Moose::Report::Time - Reporting object for timing
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 DESCRIPTION
 
@@ -88,6 +100,10 @@ method took to run. Something like:
 
   0.00177908 wallclock secs ( 0.00 usr +  0.00 sys =  0.00 CPU)
 
+=head2 C<as_hashref>
+
+Returns the C<real>, C<user>, and C<system> time values in a hashref.
+
 =head1 AUTHORS
 
 =over 4
@@ -104,7 +120,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
