@@ -1,7 +1,11 @@
 package Test::Class::Moose::Role::AutoUse;
-$Test::Class::Moose::Role::AutoUse::VERSION = '0.62';
+
 # ABSTRACT: Automatically load the classes you're testing
 
+use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose::Role;
 use Carp 'confess';
 
@@ -40,7 +44,7 @@ Test::Class::Moose::Role::AutoUse - Automatically load the classes you're testin
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -212,7 +216,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
