@@ -1,8 +1,11 @@
 package Test::Class::Moose::Role::Executor;
-$Test::Class::Moose::Role::Executor::VERSION = '0.62';
+
 # ABSTRACT: Common code for Runner classes
 
 use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose::Role 2.0000;
 use Carp;
 use namespace::autoclean;
@@ -26,9 +29,8 @@ has 'test_configuration' => (
 );
 
 has 'test_report' => (
-    is      => 'rw',
+    is      => 'ro',
     isa     => 'Test::Class::Moose::Report',
-    writer  => '__set_test_report',
     builder => '_build_test_report',
 );
 
@@ -39,50 +41,10 @@ sub _build_test_report {
     # types of Executors. However, the real fix is to make parallel reporting
     # actually work so the report doesn't have to care about this.
     return Test::Class::Moose::Report->new(
-        is_parallel => (ref $self) =~ /::Parallel$/ ? 1 : 0,
+        is_parallel => ( ref $self ) =~ /::Parallel$/ ? 1 : 0,
     );
 }
 
-sub _tcm_run_test_class {
-    my ( $self, $test_class ) = @_;
-
-    return sub {
-        local *__ANON__ = 'ANON_TCM_RUN_TEST_CLASS';
-
-        my %test_instances
-            = $test_class->_tcm_make_test_class_instances(
-            $self->test_configuration->args );
-
-        unless (%test_instances) {
-            my $message = "Skipping '$test_class': no test instances found";
-            $self->test_configuration->builder->plan(skip_all => $message);
-            return;
-        }
-
-        foreach my $test_instance_name (sort keys %test_instances) {
-            my $test_instance = $test_instances{$test_instance_name};
-
-            if ( values %test_instances > 1 ) {
-                $self->test_configuration->builder->subtest(
-                    $test_instance_name,
-                    sub {
-                        $self->_tcm_run_test_instance(
-                            $test_instance_name,
-                            $test_instance,
-                        );
-                    },
-                );
-            }
-            else {
-                $self->_tcm_run_test_instance(
-                    $test_instance_name,
-                    $test_instance,
-                );
-            }
-        }
-    };
-}
-
 sub _tcm_run_test_instance {
     my ( $self, $test_instance_name, $test_instance ) = @_;
 
@@ -90,14 +52,13 @@ sub _tcm_run_test_instance {
     my $builder = $config->builder;
     my $report  = $self->test_report;
 
-    $test_instance->__set_test_report($report);
-
     # set up test class reporting
     my $instance_report = Test::Class::Moose::Report::Instance->new(
         {   name => $test_instance_name,
         }
     );
-    $report->add_test_instance($instance_report);
+    $report->current_class->add_test_instance($instance_report)
+      if $report->current_class;
 
     my @test_methods = $self->_tcm_test_methods_for_instance($test_instance);
 
@@ -106,28 +67,31 @@ sub _tcm_run_test_instance {
         $instance_report->skipped($message);
         $instance_report->passed(1);
         $builder->plan( skip_all => $message );
-        return;
+        return $instance_report;
     }
     $instance_report->_start_benchmark;
 
     $report->_inc_test_methods( scalar @test_methods );
 
     # startup
-    if (!$self->_tcm_run_test_control_method(
+    unless (
+        my $report = $self->_tcm_run_test_control_method(
             $test_instance, 'test_startup', $instance_report
         )
       )
     {
         fail "test_startup failed";
-        return;
+        $instance_report->passed(0);
+        return $instance_report;
     }
 
     if ( my $message = $test_instance->test_skip ) {
 
         # test_startup skipped the class
         $instance_report->skipped($message);
+        $instance_report->passed(1);
         $builder->plan( skip_all => $message );
-        return;
+        return $instance_report;
     }
 
     $builder->plan( tests => scalar @test_methods );
@@ -136,13 +100,13 @@ sub _tcm_run_test_instance {
 
     my $all_passed = 1;
     foreach my $test_method (@test_methods) {
-        my $report_method = $self->_tcm_run_test_method(
+        my $method_report = $self->_tcm_run_test_method(
             $test_instance,
             $test_method,
             $instance_report,
         );
-        $report->_inc_tests( $report_method->num_tests_run );
-        $all_passed = 0 if not $report_method->passed;
+        $report->_inc_tests( $method_report->num_tests_run );
+        $all_passed = 0 if not $method_report->passed;
     }
     $instance_report->passed($all_passed);
 
@@ -213,42 +177,56 @@ sub _tcm_filter_by_tag {
         my @new_method_list = @filtered_methods;
         foreach my $method (@filtered_methods) {
             foreach my $tag (@$exclude) {
-                if (
-                    Test::Class::Moose::AttributeRegistry->method_has_tag(
+                if (Test::Class::Moose::AttributeRegistry->method_has_tag(
                         $class, $method, $tag
                     )
                   )
                 {
-                  @new_method_list = grep { $_ ne $method } @new_method_list;
+                    @new_method_list
+                      = grep { $_ ne $method } @new_method_list;
                 }
             }
-        };
+        }
         @filtered_methods = @new_method_list;
-    };
+    }
     return @filtered_methods;
 }
 
-my $TEST_CONTROL_METHODS = sub {
-    local *__ANON__ = 'ANON_TEST_CONTROL_METHODS';
-    return {
-        map { $_ => 1 }
-          qw/
-          test_startup
-          test_setup
-          test_teardown
-          test_shutdown
-          /
-    };
-};
+my %TEST_CONTROL_METHODS = map { $_ => 1 } qw/
+  test_startup
+  test_setup
+  test_teardown
+  test_shutdown
+  /;
 
 sub _tcm_run_test_control_method {
     my ( $self, $test_instance, $phase, $report_object ) = @_;
 
-    $TEST_CONTROL_METHODS->()->{$phase}
+    $TEST_CONTROL_METHODS{$phase}
       or croak("Unknown test control method ($phase)");
 
+    my %report_args = (
+        name     => $phase,
+        instance => (
+              $report_object->isa('Test::Class::Moose::Report::Method')
+            ? $report_object->instance
+            : $report_object
+        )
+    );
+    my $phase_method_report
+      = Test::Class::Moose::Report::Method->new( \%report_args );
+
+    my $set_meth = "set_${phase}_method";
+    $report_object->$set_meth($phase_method_report);
+
     my $success;
     my $builder = $self->test_configuration->builder;
+
+    # It'd be nicer to start and end immediately after we call
+    # $test_instance->$phase but we can't guarantee that those calls would
+    # happen inside the try block.
+    $phase_method_report->_start_benchmark;
+
     try {
         my $num_tests = $builder->current_test;
         $test_instance->$phase($report_object);
@@ -262,16 +240,19 @@ sub _tcm_run_test_control_method {
         my $class = $test_instance->test_class;
         $builder->diag("$class->$phase() failed: $error");
     };
+
+    $phase_method_report->_end_benchmark;
+
     return $success;
 }
 
 sub _tcm_run_test_method {
     my ( $self, $test_instance, $test_method, $instance_report ) = @_;
 
-    my $report  = Test::Class::Moose::Report::Method->new(
-        { name => $test_method, instance_report => $instance_report } );
+    my $report = Test::Class::Moose::Report::Method->new(
+        { name => $test_method, instance => $instance_report } );
 
-    $self->test_report->current_instance->add_test_method($report);
+    $instance_report->add_test_method($report);
     my $config = $self->test_configuration;
 
     my $builder = $config->builder;
@@ -311,8 +292,7 @@ sub _tcm_run_test_method {
             $report->_end_benchmark;
             if ( $config->show_timing ) {
                 my $time = $report->time->duration;
-                $config->builder->diag(
-                    $report->name . ": $time" );
+                $config->builder->diag( $report->name . ": $time" );
             }
         },
     );
@@ -322,7 +302,7 @@ sub _tcm_run_test_method {
         $test_instance,
         'test_teardown',
         $report,
-    ) or $report->passed(fail "test_teardown failed");
+    ) or $report->passed( fail "test_teardown failed" );
     if ( !$report->is_skipped ) {
         $report->num_tests_run($num_tests);
         if ( !$report->has_plan ) {
@@ -366,7 +346,9 @@ Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.62
+version 0.67
+
+=for Pod::Coverage test_classes
 
 =head1 AUTHORS
 
@@ -384,7 +366,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
