@@ -1,19 +1,22 @@
 package Test::Class::Moose::Role::ParameterizedInstances;
-$Test::Class::Moose::Role::ParameterizedInstances::VERSION = '0.62';
+
 # ABSTRACT: run tests against multiple instances of a test class
 
+use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose::Role;
 
 requires '_constructor_parameter_sets';
 
 sub _tcm_make_test_class_instances {
-    my ( $class, $args ) = @_;
-
-    my %base_args = %{$args};
+    my $class     = shift;
+    my %base_args = @_;
 
     my %sets = $class->_constructor_parameter_sets;
     return map { $_ => $class->new( %{ $sets{$_} }, %base_args ) }
-        keys %sets;
+      keys %sets;
 }
 
 1;
@@ -28,7 +31,7 @@ Test::Class::Moose::Role::ParameterizedInstances - run tests against multiple in
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 AUTHORS
 
@@ -46,7 +49,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
