@@ -1,11 +1,13 @@
 package Test::Class::Moose::Role::Reporting;
-$Test::Class::Moose::Role::Reporting::VERSION = '0.62';
+
 # ABSTRACT: Reporting gathering role
 
+use 5.10.0;
+
+our $VERSION = '0.67';
+
 use Moose::Role;
-use Benchmark qw(timediff timestr :hireswallclock);
-use Test::Class::Moose::Report::Time;
-with 'Test::Class::Moose::Role::Timing';
+with 'Test::Class::Moose::Role::HasTimeReport';
 
 has 'name' => (
     is       => 'ro',
@@ -43,7 +45,7 @@ Test::Class::Moose::Role::Reporting - Reporting gathering role
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 DESCRIPTION
 
@@ -51,7 +53,7 @@ Note that everything in here is experimental and subject to change.
 
 =head1 IMPLEMENTS
 
-L<Test::Class::Moose::Role::Timing>.
+L<Test::Class::Moose::Role::HasTimeReport>.
 
 =head1 REQUIRES
 
@@ -84,7 +86,7 @@ Returns true if the class or method passed.
 
 =head2 C<time>
 
-(From L<Test::Class::Moose::Role::Timing>)
+(From L<Test::Class::Moose::Role::HasTimeReport>)
 
 Returns a L<Test::Class::Moose::Report::Time> object. This object
 represents the duration of this class or method.
@@ -105,7 +107,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
