@@ -1,7 +1,11 @@
 package Test::Class::Moose::Tutorial;
-$Test::Class::Moose::Tutorial::VERSION = '0.62';
+
 # ABSTRACT: A starting guide for Test::Class::Moose
 
+use 5.10.0;
+
+our $VERSION = '0.67';
+
 # there is no code here, but we're moving this from .pod to .pm to try to work
 # around a strange bug where this is showing up instead of main docs on
 # metacpan and cpan
@@ -18,7 +22,7 @@ Test::Class::Moose::Tutorial - A starting guide for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.62
+version 0.67
 
 =head1 Getting Started
 
@@ -375,7 +379,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
